import { MaybeRefOrGetter } from '@vueuse/core';
import { ActiveFilter, FieldSchema, Filter } from '../types';
/**
 * Checks if a value is within a date range
 * @param from ISO string date from which the range starts
 * @param to ISO string date at which the range ends
 * @param value ISO string date to check
 * @returns Whether the value is within the date range
 */
export declare function isInDateRange(from: string, to: string, value: string): boolean;
/**
 * Checks if a value matches the filters provided
 * @param value The value to check
 * @param filters The filters to check against
 * @returns Whether the value matches the filters
 */
export declare function isMatchingFilters(value: string, filters: Omit<ActiveFilter, 'name'>[]): boolean;
/**
 * Checks if a value matches the search provided
 * @param value The value to check
 * @param search The search to check against
 * @returns Whether the value matches the search
 */
export declare function isMatchingSearch(value: string | undefined, search: string): boolean;
/**
 * Gets the available filters based on the data and fields provided
 * @param data The data to get the filters from
 * @param fields The fields to get the filters for
 * @returns The available filters
 */
export declare function getAvailableFilters<T extends Record<string, any>>(data?: T[], fields?: readonly FieldSchema[]): Filter[] | undefined;
/**
 * Composable to filter data based on active filters and search provided
 *
 * ## Example usage
 *
 * ```ts
 * import { defineFieldSchema } from 'weightmans-ui-vue/utils'
 *
 * const data = ref([
 *  { employee: { id: '1', name: 'John Doe' }, date: '2021-01-01' },
 *  { employee: { id: '2', name: 'Jane Doe' }, date: '2021-01-02' },
 *  { employee: { id: '3', name: 'Lorem Doe' }, date: '2021-01-03' },
 * ])
 *
 * const employeeSchema = defineFieldSchema({
 *   name: 'employee',
 *   type: 'text',
 *   label: 'Employee',
 *   getValue: (raw: { id: string, name: string }) => raw.id,
 *   getDisplayValue: (raw: { id: string, name: string }) => raw.name,
 * })
 *
 * const dateSchema = defineFieldSchema({
 *   name: 'date',
 *   type: 'date',
 *   label: 'Date',
 * })
 *
 * const {
 *  filteredData,
 *  availableFilters,
 *  activeFilters,
 *  search,
 * } = useFilters(data, [employeeSchema, dateSchema])
 *
 * // Search for 'John'
 * search.value = 'John'
 * console.log(filteredData.value) // [{ employee: { id: '1', name: 'John Doe' }, date: '2021-01-01' }]
 *
 * // Filter by employee id 1
 * activeFilters.value.push({ name: 'employee', filters: [{ type: 'text', value: '3' }] })
 *
 * console.log(filteredData.value) // [{ employee: { id: '3', name: 'Lorem Doe' }, date: '2021-01-03' }]
 * ```
 *
 * @param data Array of items to filter
 * @param fields The fields schema to use for filtering
 */
export declare function useFilters<T extends Record<string, any>>(data: MaybeRefOrGetter<T[] | undefined>, fields: MaybeRefOrGetter<Readonly<FieldSchema[]> | undefined>): {
    /**
     * The data after applying the filters and search query
     */
    filteredData: globalThis.ComputedRef<T[] | undefined>;
    /**
     * List of available filters, generated from the data and fields provided
     */
    availableFilters: globalThis.ComputedRef<Filter[] | undefined>;
    /**
     * The active filters ref that can be used for `v-model` binding
     * @type {Ref<ActiveFilter[]>}
     */
    activeFilters: globalThis.Ref<({
        name: string;
        type: "text";
        value: string;
    } | {
        name: string;
        type: "date";
        value: {
            from: string;
            to: string;
        };
    })[], ActiveFilter[] | ({
        name: string;
        type: "text";
        value: string;
    } | {
        name: string;
        type: "date";
        value: {
            from: string;
            to: string;
        };
    })[]>;
    /**
     * The search query ref that can be used for `v-model` binding
     */
    search: globalThis.Ref<string, string>;
};
export default useFilters;
