import { MaybeRefOrGetter } from '@vueuse/core';
/**
 * Groups the data by a key
 *
 * ## Example usage
 *
 * ```ts
 * const data = ref([
 *  { id: 1, name: 'John', age: 20 },
 *  { id: 2, name: 'Jane', age: 30 },
 *  { id: 3, name: 'Doe', age: 20 },
 * ])
 *
 * const groupBy = ref<keyof typeof data[number]>('age')
 *
 * const { groupedData } = useGroup(data, groupBy, 'people')
 *
 * console.log(groupedData.value) // [
 * //   {
 * //     age: 20,
 * //     people: [
 * //       { id: 1, name: 'John' },
 * //       { id: 3, name: 'Doe' },
 * //     ],
 * //   },
 * //   {
 * //     age: 30,
 * //     people: [
 * //       { id: 2, name: 'Jane' },
 * //     ],
 * //   },
 * // ]
 * ```
 *
 * @param data The data to group
 * @param groupBy The key to group by
 * @param groupedKey The key to store the grouped data
 * @returns The grouped data
 */
export declare function useGroup<T extends Record<string, any>, TKey extends keyof T, TGroupKey extends string>(data: MaybeRefOrGetter<T[] | undefined>, groupBy: MaybeRefOrGetter<TKey>, groupedKey: MaybeRefOrGetter<TGroupKey>): {
    /**
     * The grouped data
     */
    groupedData: globalThis.ComputedRef<({ [K in TKey]: T[TKey]; } & { [K_1 in TGroupKey]: Omit<T, TKey>[]; })[] | undefined>;
};
export default useGroup;
