import { Notification, NotificationOptions } from '../types';
/**
 * Composable to manage notifications within the application.
 * Notifications are stored in a reactive array and can be pushed, dismissed, paused, resumed, or updated.
 * This composable is managed globally and the instance can be accessed from any component.
 *
 * ## Example usage
 *
 * ```ts
 * const {
 *   notifications,
 *   pushNotification,
 *   dismissNotification,
 *   setNotification
 * } = useNotifications()
 *
 * pushNotification({
 *  type: 'success',
 *  title: 'Success',
 *  message: 'This is a success notification',
 * })
 *
 * console.log(notifications.value) // [{ id: '...', type: 'success', title: 'Success', message: 'This is a success notification' }]
 *  ```
 */
export declare const useNotifications: () => {
    /**
     * The notifications currently stored in the application.
     */
    notifications: globalThis.Ref<{
        id: string;
        message: string;
        type?: import('../types').NotificationType | undefined;
        onClick?: (() => void) | undefined;
        category?: string | undefined;
        persistent?: boolean | undefined;
        timer?: {
            ref: () => NodeJS.Timeout;
            unref: () => NodeJS.Timeout;
            hasRef: () => boolean;
            refresh: () => NodeJS.Timeout;
            [Symbol.toPrimitive]: () => number;
            [Symbol.dispose]: () => void;
        } | undefined;
    }[], Notification[] | {
        id: string;
        message: string;
        type?: import('../types').NotificationType | undefined;
        onClick?: (() => void) | undefined;
        category?: string | undefined;
        persistent?: boolean | undefined;
        timer?: {
            ref: () => NodeJS.Timeout;
            unref: () => NodeJS.Timeout;
            hasRef: () => boolean;
            refresh: () => NodeJS.Timeout;
            [Symbol.toPrimitive]: () => number;
            [Symbol.dispose]: () => void;
        } | undefined;
    }[]>;
    /**
     * Push a new notification
     */
    pushNotification: (value: NotificationOptions) => Notification;
    /**
     * Dismiss a notification by its id
     */
    dismissNotification: (id: string) => void;
    /**
     * Pause a notification timer by its id
     */
    pauseNotificationTimer: (id: string) => void;
    /**
     * Resume a notification timer by its id
     */
    resumeNotificationTimer: (id: string) => void;
    /**
     * Modify a notification by its id
     */
    setNotification: (notification: Notification) => void;
};
export default useNotifications;
