import { MaybeRefOrGetter } from '@vueuse/core';
/**
 * Paginates the items in the collection
 *
 * ## Example usage
 *
 * ```ts
 *  const data = [1, 2, 3, 4, 5, 6, 7, 8]
 *
 *  const {
 *    paginatedData,
 *    next,
 *    first,
 *    last,
 *  } = usePagination(data, {
 *    pageSize: 3,
 *  })
 *
 *  console.log(paginatedData.value) // [1, 2, 3]
 *  ```
 *
 * @param data The collection to paginate
 * @param options The pagination initial options (page, pageSize)
 * @param options.page The initial page number
 * @param options.pageSize The initial page size
 * @returns The pagination object
 */
export declare function usePagination<T extends any[] | undefined>(data: MaybeRefOrGetter<T>, options?: {
    /**
     * Initial page number
     */
    page?: number;
    /**
     * Initial page size
     */
    pageSize?: number;
}): {
    /**
     * Total number of pages
     */
    pageCount: globalThis.ComputedRef<number>;
    /**
     * Current page number
     */
    currentPage: globalThis.Ref<number, number>;
    /**
     * Current number of items per page
     */
    currentPageSize: globalThis.Ref<number, number>;
    /**
     * Whether the current page is the first page
     */
    isFirstPage: globalThis.ComputedRef<boolean>;
    /**
     * The paginated subset of data array
     */
    paginatedData: globalThis.ComputedRef<T>;
    /**
     * Go to the next page
     */
    next: () => void;
    /**
     * Go to the previous page
     */
    prev: () => void;
    /**
     * Go to the last page
     */
    last: () => void;
    /**
     * Go to the first page
     */
    first: () => void;
};
export default usePagination;
