import { MaybeRefOrGetter } from '@vueuse/core';
import { FieldSchema, SortDirection } from '../types';
/**
 * Sorts the data by the specified field
 *
 * ## Example usage
 *
 * ```ts
 * import { defineFieldSchema } from 'weightmans-ui-vue/utils'
 *
 * const employeeSchema = defineFieldSchema({
 *  name: 'employee',
 *  type: 'text',
 *  label: 'Employee',
 *  getValue: (raw: { id: string, name: string }) => raw.id,
 *  getDisplayValue: (raw: { id: string, name: string }) => raw.name,
 * })
 *
 * const date = defineFieldSchema({
 *  name: 'date',
 *  type: 'date',
 *  label: 'Date',
 * })
 *
 * const data = ref([
 *  { employee: { id: '1', name: 'David' }, date: '2021-01-01' },
 *  { employee: { id: '2', name: 'Bob' }, date: '2021-01-02' },
 *  { employee: { id: '3', name: 'Alice' }, date: '2021-01-03' },
 *  { employee: { id: '4', name: 'Charlie' }, date: '2021-01-04' }
 * ])
 *
 * const {
 *  sortedData,
 *  sortBy,
 *  sortDirection,
 *  toggleSort,
 * } = useSort(data, [employeeSchema, date])
 *
 * toggleSort('employee')
 *
 * console.log(sortedData.value) // [{ employee: { id: '3', name: 'Alice' }, date: '2021-01-03' }, { employee: { id: '2', name: 'Bob' }, date: '2021-01-02' }, { employee: { id: '4', name: 'Charlie' }, date: '2021-01-04' }, { employee: { id: '1', name: 'David' }, date: '2021-01-01' }]
 *
 * ```
 *
 * @param data The data to sort
 * @param fieldSchema Field schema of the data
 * @returns The sorted data, the field to sort by, the sort direction, and a function to toggle the sort direction
 */
export declare function useSort<T extends Record<string, any>>(data: MaybeRefOrGetter<T[] | undefined>, fieldSchema: MaybeRefOrGetter<readonly FieldSchema<string>[]>): {
    /**
     * The sorted data
     */
    sortedData: globalThis.ComputedRef<T[] | undefined>;
    /**
     * The field to sort by
     */
    sortBy: globalThis.Ref<keyof T | undefined, keyof T | undefined>;
    /**
     * The direction to sort by
     */
    sortDirection: globalThis.Ref<SortDirection, SortDirection>;
    /**
     * Toggles the sort direction between `asc`, `desc`, and `null`
     */
    toggleSort: (name: keyof T) => void;
};
export default useSort;
