import { VNodeArrayChildren } from 'vue';
import { FieldSchema } from './types';
import { formatTimeAgo } from '@vueuse/core';
/**
 * Converts slot content to string
 */
export declare const getSlotChildrenText: (children: VNodeArrayChildren) => string;
/**
 * Returns a promise that resolves after the specified time
 * @param ms The time to wait in milliseconds
 * @returns A promise that resolves after the specified time
 */
export declare const sleep: (ms: number) => Promise<unknown>;
/**
 * Returns the position of a value between a min and max value
 * @param value The value to calculate the position
 * @param minValue The minimum value
 * @param maxValue The maximum value
 * @returns The position of the value between the min and max value in percentage (0-100) 0% = minValue, 100% = maxValue
 */
export declare function getPosition(value?: number, minValue?: number, maxValue?: number): number | undefined;
/**
 * Strips the time component from a Date object, leaving only the month, day, and year.
 * @param date - The Date object to strip the time from.
 * @returns A new Date object with the time set to 00:00:00.
 */
export declare function stripTime(date: Date | string): Date;
/**
 * Returns the result of a function if it exists, otherwise returns the value.
 * @param fn - The function to call.
 * @param value - The value to return if the function does not exist.
 * @returns The result of the function if it exists, otherwise the value.
 */
export declare function fnOrValue<T, R>(fn: ((value: T) => R) | undefined, value: T): R | T;
/**
 * Helper function to define a field schema
 */
export declare function defineFieldSchema<T, TKey extends string, TRaw = any>(field: FieldSchema<TKey, TRaw, T>): FieldSchema<TKey, TRaw, T>;
/**
 * Capitalizes the first letter of a string
 * @param str The string to capitalize
 * @returns The string with the first letter capitalized
 */
export declare function capitalizeFirstLetter(str: string): string;
/**
 * Formats a number as a currency
 * @example currencyFormatter(1234.56) === '£1,234.56'
 */
export declare const currencyFormatter: {
    (value: number): string;
    (value: number | bigint): string;
};
/**
 * Formats a number as days
 * @example
 * daysFormatter(1) === '1 day'
 * daysFormatter(2) === '2 days'
 */
export declare const daysFormatter: {
    (value: number): string;
    (value: number | bigint): string;
};
/**
 * Formats a number as a percentage with 2 decimal places
 * @example
 * percentageFormatter(0.1234) === '12.34%'
 * percentageFormatter(0) === '0.00%'
 * percentageFormatter(1) === '100.00%'
 */
export declare const percentageFormatter: {
    (value: number): string;
    (value: number | bigint): string;
};
/**
 * Formats a number as a decimal with 2 decimal places
 * @example
 * decimalFormatter(1234.56) === '1,234.56'
 * decimalFormatter(1234) === '1,234.00'
 */
export declare const decimalFormatter: {
    (value: number): string;
    (value: number | bigint): string;
};
/**
 * Displays a friendly date and time
 * @example
 * dateTimeFormatter(new Date('2021-01-01T12:34:56')) === '1 Jan 2021, 12:34'
 */
export declare const dateTimeFormatter: (date?: Date | number) => string;
/**
 * Formats a date with friendly date (no time)
 * @param date  - The string date to format
 * @returns  The formatted date
 * @example
 * dateFormatter(new Date('2021-01-01')) === '1 Jan 2021'
 */
export declare const dateFormatter: (date?: Date | number) => string;
/**
 * Formats a date as a monthly period (month and year)
 * @param date - The string date to format
 * @returns The formatted date
 * @example
 * periodFormatter(new Date('2021-01-01')) === 'January 2021'
 */
export declare const periodFormatter: (date?: Date | number) => string;
/**
 * Formats a date as a time ago
 * @example
 * timeAgoFormatter(new Date('2021-01-01'), new Date('2021-06-01')) === '6 months ago'
 * timeAgoFormatter(new Date('2021-01-01'), new Date('2021-01-02')) === '1 day ago'
 */
export declare const timeAgoFormatter: typeof formatTimeAgo;
/**
 * Gets the initials of a user
 * @param name - The name of the user
 * @returns The initials
 */
export declare function getUserInitials(name?: string): string;
